import { GeocodingCore } from '@mapbox/search-js-core';
import { renderHook, act } from '@testing-library/react-hooks';

import { useGeocodingCore } from '../../src/hooks/useGeocodingCore';

const ACCESS_TOKEN = 'xyz';

describe('useGeocodingCore', () => {
  it('works with access token', () => {
    const { result, rerender } = renderHook(
      ({ accessToken }) => useGeocodingCore({ accessToken }),
      { initialProps: { accessToken: ACCESS_TOKEN } }
    );

    expect(result.current).toEqual(expect.any(GeocodingCore));
    expect(result.current.accessToken).toEqual(ACCESS_TOKEN);

    act(() => {
      rerender({ accessToken: 'abc' });
    });

    expect(result.current.accessToken).toEqual('abc');
  });

  it('works with options', () => {
    const { result, rerender } = renderHook(
      ({ options }) =>
        useGeocodingCore({ accessToken: ACCESS_TOKEN, ...options }),
      { initialProps: { options: {} } }
    );

    expect(result.current).toEqual(expect.any(GeocodingCore));

    act(() => {
      rerender({ options: { language: 'jp' } });
    });

    expect(result.current.defaults).toEqual({
      language: 'jp'
    });

    // Make sure previous language is "undone".
    act(() => {
      rerender({ options: { proximity: [0, 0] } });
    });

    expect(result.current.defaults).toEqual({
      proximity: [0, 0]
    });
  });
});
