import {
  AddressAutofillCore,
  SearchBoxCore,
  GeocodingCore,
  SearchSession
} from '@mapbox/search-js-core';
import { renderHook, act } from '@testing-library/react-hooks';
import { useSearchSession } from '../../src/hooks/useSearchSession';

const AUTOFILL = new AddressAutofillCore();
const SEARCHBOX = new SearchBoxCore();
const GEOCODING = new GeocodingCore();

test('useSearchSession', () => {
  const { result, rerender } = renderHook(
    ({ search }) => useSearchSession(search),
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    { initialProps: { search: AUTOFILL as any } }
  );

  const one = result.current;
  expect(one).toEqual(expect.any(SearchSession));
  expect(one.search).toEqual(AUTOFILL);

  act(() => {
    rerender({ search: SEARCHBOX });
  });

  const two = result.current;
  expect(two).toEqual(expect.any(SearchSession));
  expect(two.search).toEqual(SEARCHBOX);

  expect(one).not.toBe(two);

  act(() => {
    rerender({ search: GEOCODING });
  });

  const three = result.current;
  expect(three).toEqual(expect.any(SearchSession));
  expect(three.search).toEqual(GEOCODING);

  expect(two).not.toBe(three);
});
